/// <reference types="node" />
import { AuthType } from "../enums/AuthType";
import { ConnectionType } from "../enums/ConnectionType";
import { NodeTrustedMailcore2NativeBinding } from "../types/NodeTrustedMailcore2NativeBinding";
import { ISMTPAsyncSessionNativeBinding } from '../types';
import { DsnNotify } from "../enums/DsnNotify";
declare const bindings: NodeTrustedMailcore2NativeBinding;
/**
 * ISMTPAsyncSession Class
 *
 * @public
 */
declare class SMTPAsyncSession extends bindings.ISMTPAsyncSession {
    protected handle: ISMTPAsyncSessionNativeBinding;
    constructor();
    /**
     * Set hostname
     *
     * @memberof SMTPAsyncSession
     */
    set hostname(hostname: string);
    /**
     * Get hostname
     *
     * @type {string}
     * @memberof SMTPAsyncSession
     */
    get hostname(): string;
    /**
     * Set port
     *
     * @memberof SMTPAsyncSession
     */
    set port(port: number);
    /**
     * Get port
     *
     * @type {number}
     * @memberof SMTPAsyncSession
     */
    get port(): number;
    /**
     * Set string
     *
     * @memberof SMTPAsyncSession
     */
    set username(username: string);
    /**
     * Get string
     *
     * @type {string}
     * @memberof SMTPAsyncSession
     */
    get username(): string;
    /**
     * Set password
     *
     * @memberof SMTPAsyncSession
     */
    set password(password: string);
    /**
     * Get password
     *
     * @type {string}
     * @memberof SMTPAsyncSession
     */
    get password(): string;
    /**
     * Set checkCertificateEnabled
     *
     * @memberof SMTPAsyncSession
     */
    set checkCertificateEnabled(isEnabled: boolean);
    /**
     * Get checkCertificateEnabled
     *
     * @type {boolean}
     * @memberof SMTPAsyncSession
     */
    get checkCertificateEnabled(): boolean;
    /**
     * Set OAuth2Token
     *
     * @memberof SMTPAsyncSession
     */
    set OAuth2Token(OAuth2Token: string);
    /**
     * Get OAuth2Token
     *
     * @type {string}
     * @memberof SMTPAsyncSession
     */
    get OAuth2Token(): string;
    /**
     * Set authType
     *
     * @memberof SMTPAsyncSession
     */
    set authType(authType: AuthType);
    /**
     * Get authType
     *
     * @type {AuthType}
     * @memberof SMTPAsyncSession
     */
    get authType(): AuthType;
    /**
     * Set connectionType
     *
     * @memberof SMTPAsyncSession
     */
    set connectionType(connectionType: ConnectionType);
    /**
     * Get connectionType
     *
     * @type {ConnectionType}
     * @memberof SMTPAsyncSession
     */
    get connectionType(): ConnectionType;
    /**
     * Validate exist account
     *
     * @param {string} from address
     * @returns {number} 0 - success, other - failure
     *
     * @memberof SMTPAsyncSession
     */
    checkAccount(from: string): Promise<number>;
    /**
     * Send message to smtp server
     *
     * @param {string | Buffer} message message
     * @returns {number} error code. 0 - success, other - failure
     *
     * @memberof SMTPAsyncSession
     */
    sendMessage(message: string | Buffer): Promise<number>;
    /**
     * Send message to smtp server
     *
     * @param {string} from address
     * @param {string[]} recipients recipients
     * @param {string | Buffer} message message body
     * @param {*} [notify=DsnNotify.DsnNotifyNone] DSN_NOTIFY. Default disabled
     * @returns {number} error code. 0 - success, other - failure
     *
     * @memberof SMTPAsyncSession
     */
    sendMessageOperation(from: string, recipients: string[], message: string | Buffer, notify?: DsnNotify): Promise<number>;
    /**
     * Disconnect connection
     *
     * @memberof SMTPAsyncSession
     */
    disconnect(): void;
    /**
     * Validate connection status
     *
     * @returns {boolean}
     *
     * @memberof SMTPAsyncSession
     */
    isDisconnected(): boolean;
}
export { SMTPAsyncSession };
//# sourceMappingURL=SMTPAsyncSession.d.ts.map